aiodagpi
========

.. image:: https://img.shields.io/pypi/v/aiodagpi.svg
    :target: https://pypi.python.org/pypi/aiodagpi
    :alt: Latest PyPI version

.. image:: https://img.shields.io/badge/license-MIT-yellowgreen
    :target: https://mit-license.org
    :alt: MIT License link

.. image:: https://img.shields.io/badge/api-dagpi-yellow
    :target: https://dagpi.tk
    :alt: Dagpi.tk link

.. image:: https://img.shields.io/badge/python-3.6%2B-blue
    :target: https://www.python.org/downloads/
    :alt: Pythom version 3.6 and above

An asynchronous python API wrapper for Dagpi : https://dagpi.tk

Usage
-----

CURRENTLY IN PLANNING, PAGE USED FOR RESERVATION.

Installation
------------

Requirements
^^^^^^^^^^^^

Compatibility
-------------

Licence
-------

Authors
-------

`aiodagpi` was written by `Raj Sharma <yrsharma@icloud.com>`_.
